@@ -173,14 +173,20 @@ around run => sub ( $orig, $self, $req ) {
         $self->{ext_app_namespace} => $self->{path},
     };
 
+    # CloudFlare CDN
+    # https://cdnjs.com/libraries/extjs
+
+    my $extjs_ver       = '6.2.0';
+    my $extjs_framework = 'classic';
+
     my $resources = {
         INDEX => { title => 'Admin', },
         ext   => {
-            extjs          => "/static/sencha/ext/build/ext-${ext_framework_name}all${debug}.js",
-            extjs_ux       => "/static/sencha/ext/build/packages/ux/$framework/ux${debug}.js",
-            theme_css      => "/static/sencha/ext/build/$framework/theme-$theme/resources/theme-$theme-all${debug}.css",
-            theme_js       => "/static/sencha/ext/build/$framework/theme-$theme/theme-$theme${debug}.js",
-            locale_js      => "/static/sencha/ext/build/$framework/locale/locale-@{[$self->locale]}${debug}.js",
+            extjs          => "https://cdnjs.cloudflare.com/ajax/libs/extjs/$extjs_ver/ext-all${debug}.js",
+            extjs_ux       => "https://cdnjs.cloudflare.com/ajax/libs/extjs/$extjs_ver/packages/ux/$extjs_framework/ux.js",
+            theme_css      => "https://cdnjs.cloudflare.com/ajax/libs/extjs/$extjs_ver/$extjs_framework/theme-${theme}/resources/theme-${theme}-all${debug}.css",
+            theme_js       => "https://cdnjs.cloudflare.com/ajax/libs/extjs/$extjs_ver/$extjs_framework/theme-${theme}/theme-${theme}${debug}.js",
+            locale_js      => "https://cdnjs.cloudflare.com/ajax/libs/extjs/$extjs_ver/$extjs_framework/locale/locale-@{[$self->locale]}${debug}.js",
             api_map        => undef,
             loader_path    => mark_raw( to_json( $loader_path, readable => $devel )->$* ),
             app_namespace  => $self->{ext_app_namespace},
@@ -188,6 +194,21 @@ around run => sub ( $orig, $self, $req ) {
         },
     };
 
+    # my $resources = {
+    #     INDEX => { title => 'Admin', },
+    #     ext   => {
+    #         extjs          => "/static/sencha/ext/build/ext-${ext_framework_name}all${debug}.js",
+    #         extjs_ux       => "/static/sencha/ext/build/packages/ux/$framework/ux${debug}.js",
+    #         theme_css      => "/static/sencha/ext/build/$framework/theme-$theme/resources/theme-$theme-all${debug}.css",
+    #         theme_js       => "/static/sencha/ext/build/$framework/theme-$theme/theme-$theme${debug}.js",
+    #         locale_js      => "/static/sencha/ext/build/$framework/locale/locale-@{[$self->locale]}${debug}.js",
+    #         api_map        => undef,
+    #         loader_path    => mark_raw( to_json( $loader_path, readable => $devel )->$* ),
+    #         app_namespace  => $self->{ext_app_namespace},
+    #         viewport_class => "$self->{ext_app_namespace}.Viewport",
+    #     },
+    # };
+
     my $index = P->tmpl->render( 'sencha/index-extjs.html', $resources );
 
     $req->( 200, [ 'Content-Type' => 'text/html; charset=UTF-8' ], $index )->finish;
